==> etherx-0.8.tar.gz: etherx-0.8/daemon/config.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Jabber
 *  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 */

#include "etherxd.h"

/* code for loading config */

xmlnode config = NULL;

void config_load(char *cfgfile)
{
    config = xmlnode_file(cfgfile);
    if (config == NULL)
    {
        fprintf(stderr,"Unable to load configuration file: %s\nUsage: etherxd -c /path/to/etherx.xml\nExiting...\n\n",cfgfile);
        exit(0);
    }
    jdebug(ZONE,"Loaded config %s.", cfgfile);
    config_include(config);
}

/* recursive include checker */
void config_include(xmlnode x)
{
    xmlnode next, load;
    static int sane = 0;

    ++sane;
    if(sane > 100)
    {
        fprintf(stderr,"Your configuration file is recursively including itself, please correct it.\nExiting...\n\n");
        exit(0);
    }

    next = xmlnode_get_firstchild(x);
    while(next != NULL)
    {
        if(j_strcmp(xmlnode_get_name(next),"include") == 0)
        {
            jdebug(ZONE,"config including %s",xmlnode_get_data(xmlnode_get_firstchild(next)));
            load = xmlnode_file(xmlnode_get_data(xmlnode_get_firstchild(next)));
            xmlnode_insert_node(x,load);
            xmlnode_free(load);
            xmlnode_hide(next);
            next = xmlnode_get_firstchild(x); /* start over, rescan after we include the new file */
            continue;
        }

        if(xmlnode_get_type(next) == NTYPE_TAG)
            config_include(next);

        next = xmlnode_get_nextsibling(next);
    }

    --sane;
}

==> etherx-0.9pre3.tar.gz: etherx-0.9pre3/daemon/config.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Jabber
 *  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 */

#include "etherxd.h"

/* code for loading config */

xmlnode config = NULL;

void config_load(char *cfgfile)
{
    config = xmlnode_file(cfgfile);
    if (config == NULL)
    {
        fprintf(stderr,"Unable to load configuration file: %s\nUsage: etherxd -c /path/to/etherx.xml\nExiting...\n\n",cfgfile);
        exit(0);
    }
    log_debug(ZONE,"Loaded config %s.", cfgfile);
    config_include(config);
}

/* recursive include checker */
void config_include(xmlnode x)
{
    xmlnode next, load;
    static int sane = 0;

    ++sane;
    if(sane > 100)
    {
        fprintf(stderr,"Your configuration file is recursively including itself, please correct it.\nExiting...\n\n");
        exit(0);
    }

    next = xmlnode_get_firstchild(x);
    while(next != NULL)
    {
        if(j_strcmp(xmlnode_get_name(next),"include") == 0)
        {
            log_debug(ZONE,"config including %s",xmlnode_get_data(xmlnode_get_firstchild(next)));
            load = xmlnode_file(xmlnode_get_data(xmlnode_get_firstchild(next)));
            xmlnode_insert_node(x,load);
            xmlnode_free(load);
            xmlnode_hide(next);
            next = xmlnode_get_firstchild(x); /* start over, rescan after we include the new file */
            continue;
        }

        if(xmlnode_get_type(next) == NTYPE_TAG)
            config_include(next);

        next = xmlnode_get_nextsibling(next);
    }

    --sane;
}
